@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List, Mapping, Sequence, Union
 
+from botocore.response import StreamingBody
+
 from .literals import (
     EncryptionStatusType,
     ErrorCauseType,
@@ -25,7 +27,7 @@ from .literals import (
     StreamStatusType,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -254,7 +256,7 @@ GetDigestRequestRequestTypeDef = TypedDict(
 GetDigestResponseTypeDef = TypedDict(
     "GetDigestResponseTypeDef",
     {
-        "Digest": bytes,
+        "Digest": StreamingBody,
         "DigestTipAddress": "ValueHolderTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
